@@ -54,12 +54,12 @@ VideoSaveOptionsPage::VideoSaveOptionsPage(QWidget *parent)
             this, &VideoSaveOptionsPage::updateFilenamePreview);
     connect(m_videoFormatComboBox.get(), &QComboBox::currentTextChanged, this, &VideoSaveOptionsPage::updateFilenamePreview);
 
-    m_ui->captureInstructionLabel->setText(captureInstructions(false));
+    m_ui->captureInstructionLabel->setText(CaptureInstructions::text(false));
     connect(m_ui->captureInstructionLabel, &QLabel::linkActivated, this, [this](const QString &link) {
         if (link == u"showmore"_s) {
-            m_ui->captureInstructionLabel->setText(captureInstructions(true));
+            m_ui->captureInstructionLabel->setText(CaptureInstructions::text(true));
         } else if (link == u"showfewer"_s) {
-            m_ui->captureInstructionLabel->setText(captureInstructions(false));
+            m_ui->captureInstructionLabel->setText(CaptureInstructions::text(false));
         } else {
             m_ui->kcfg_videoFilenameTemplate->insert(link);
         }
@@ -72,7 +72,7 @@ void VideoSaveOptionsPage::updateFilenamePreview()
 {
     const auto extension = m_videoFormatComboBox->currentData(VideoFormatModel::ExtensionRole).toString();
     const auto templateBasename = m_ui->kcfg_videoFilenameTemplate->text();
-    ::updateFilenamePreview(m_ui->preview, templateBasename + u'.' + extension);
+    ::updateFilenamePreview(m_ui->preview, templateBasename + u'.' + extension, Settings::videoSaveLocation());
 }
 
 #include "moc_VideoSaveOptionsPage.cpp"
